/*
 *  SPDX-FileCopyrightText: 2021 Felipe Kinoshita <kinofhek@gmail.com>
 *  SPDX-FileCopyrightText: 2022 Nate Graham <nate@kde.org>
 *
 *  SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */

import QtQuick
import QtQuick.Controls as QQC2
import QtQuick.Layouts
import org.kde.kirigami as Kirigami
import Qt5Compat.GraphicalEffects

import org.kde.plasma.welcome

GenericPage {
    heading: i18nc("@info:window", "Enable Third Party Repositories")
    description: xi18nc("@info:usagetip", "Click the button below to enable third-party repositories.")
    topContent: [
        Kirigami.UrlButton {
            id: thirdPartyInfoLink
            Layout.topMargin: Kirigami.Units.largeSpacing
            text: i18nc("@action:button", "See which repositories will get added")
            url: "https://docs.fedoraproject.org/en-US/workstation-working-group/third-party-repos/"
        },
        Kirigami.UrlButton {
            id: thirdPartyPolicyLink
            Layout.topMargin: Kirigami.Units.largeSpacing
            text: i18nc("@action:button", "Learn more about Fedora's Third Party Repository Policy")
            url: "https://docs.fedoraproject.org/en-US/fesco/Third_Party_Repository_Policy/"
        },
        QQC2.Button {
            id: enableThirdParty
            text: "Enable Third Party Repositories"
            onClicked: {
                Controller.runCommand("pkexec fedora-third-party enable");
                showPassiveNotification(i18n("Third-Party Repositories are now being enabled in the background."));
                disableThirdParty.visible = true;
                enableThirdParty.visible = false;
            }
            Layout.topMargin: Kirigami.Units.largeSpacing
        },
        QQC2.Button {
            id: disableThirdParty
            text: "Disable Third Party Repositories"
            onClicked: {
                Controller.runCommand("pkexec fedora-third-party disable");
                showPassiveNotification(i18n("Third-Party Repositories are now being enabled in the background."));
                disableThirdParty.visible = false;
                enableThirdParty.visible = true;
            }
            Layout.topMargin: Kirigami.Units.largeSpacing
        }

    ]
    ColumnLayout {
        anchors.fill: parent
        spacing: root.padding
        Image {
            Layout.alignment: Qt.AlignCenter
            Layout.fillWidth: true
            Layout.fillHeight: true
            Layout.maximumWidth: Kirigami.Units.gridUnit * 25

            fillMode: Image.PreserveAspectFit
            mipmap: true
            source: "/usr/share/icons/hicolor/scalable/apps/plasma-welcome-panda.svg"
        }
    }
    Component.onCompleted: Controller.runCommand("fedora-third-party query", callback)
    property var callback: (returnStatus, outputText) => {
        if (returnStatus == 0) { // App executed successfully
            if (outputText.includes('enabled') == true) {
                enableThirdParty.visible = false;
                console.log('State is Enabled');
            } else if (outputText.includes('disabled') == true) {
                disableThirdParty.visible = false;
                console.log('State is Disabled');
            } else { //What else??
                disableThirdParty.visible = false;
                console.log('State is Unknown');
            }
        } else if (returnStatus == -1) { // App not found
            disableThirdParty.visible = false;
            console.log('State is Not Found');
        } else { // And for anything else...
            disableThirdParty.visible = false;
            console.log('State is ...?');
        }
    }
}


